import { OptionData, Data } from './parser';
export interface Option {
    shortcut?: string;
    parameters?: string;
    pattern?: RegExp;
    description?: string;
}
export type Options<T> = Record<keyof T, Option>;
export type Executor<T> = (options: OptionData<T>, ...data: Data[]) => any;
export interface CommandMeta<T> extends Option {
    name: string;
    version?: string;
    options?: Options<T>;
    children?: Command<T>[];
    executor?: Executor<T>;
}
export declare class Command<T = any> {
    name: string;
    parameters: string;
    description: string;
    version: string;
    options: Options<T>;
    parent?: Command<T>;
    children: Command<T>[];
    executor?: Executor<T>;
    constructor({ name, ...meta }: CommandMeta<T>);
    static execute<T>(command: Command<T>, args: string[]): void;
    execute(options: OptionData<T>, ...data: Data[]): void;
    protected replaceShortcut(options: OptionData<T>): OptionData<T>;
    protected checkPattern(options: OptionData<T>): OptionData<T>;
    protected addPreset(): void;
    showVersion(): void;
    showHelp(command?: string): void;
    getParentNames(): Generator<string, void, unknown>;
    toString(): string;
    toOptionString(): string;
    toChildrenString(): string;
}
